@@ -11,7 +11,7 @@ import time
 import random
 import urllib
 
-import requests
+import requests  # type: ignore
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
 
 from baidupcs_py.common.date import now_timestamp
@@ -985,10 +985,8 @@ class BaiduPCS:
 
             headers = dict(PCS_HEADERS)
             headers["Cookie"] = "; ".join([f"{k}={v}" for k, v in self.cookies.items()])
-            req = urllib.request.Request(
-                url + "?" + params_str, headers=headers, method="GET"
-            )
-            resp = urllib.request.urlopen(req)
+            req = urllib.request.Request(url + "?" + params_str, headers=headers, method="GET")  # type: ignore
+            resp = urllib.request.urlopen(req)  # type: ignore
 
             # Error: "user is not authorized"
             # This error occurs when the method is called by too many times
